#
# spec file for package python-roifile
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define packagename roifile
Name:           python-roifile
Version:        2024.5.24
Release:        2.2
Summary:        Read and write ImageJ ROI format
License:        BSD-3-Clause
URL:            https://www.lfd.uci.edu/~gohlke/
Source:         https://github.com/cgohlke/roifile/archive/v%{version}.tar.gz#/roifile-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module matplotlib >= 3.2}
BuildRequires:  %{python_module numpy >= 1.15.1}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tifffile >= 2020.8.13}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-matplotlib >= 3.2
Requires:       python-numpy >= 1.15.1
Requires:       python-tifffile >= 2020.8.13
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Roifile is a Python library to read, write, create, and plot ImageJ ROIs,
an undocumented and ImageJ application specific format to store regions
of interest, geometric shapes, paths, text, and whatnot for image
overlays.

%prep
%setup -q -n %{packagename}-%{version}
# Fix warning wrong-file-end-of-line-encoding
sed -i 's/\r//' README.rst

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/%{packagename}

%python_expand %fdupes %{buildroot}%{$python_sitelib}
%prepare_alternative %{packagename}

%post
%python_install_alternative %{packagename}

%postun
%python_uninstall_alternative %{packagename}

%check
# Test not given

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/%{packagename}
%{python_sitelib}/%{packagename}
%{python_sitelib}/%{packagename}-%{version}.dist-info

%changelog
* Wed Jul 17 2024 Ben Greiner <code@bnavigator.de>
- Revert numpy < 2 restriction
* Wed Jul 17 2024 Steve Kowalik <steven.kowalik@suse.com>
- Restrict numpy to < 2 for now.
- Switch to pyproject macros.
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.5.24:
  * Fix GitHub not correctly rendering docstring examples.
* Thu Mar 21 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.3.20:
  * Fix writing generator of ROIs (#9).
* Sun Jan 21 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.1.10:
  * Support text rotation.
  * Improve text rendering.
  * Avoid array copies.
  * Limit size read from files.
* Wed Dec 13 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.8.30:
  * Fix linting issues.
  * Add py.typed marker.
  * Improve object repr and type hints.
  * Drop support for Python 3.8 and numpy < 1.21
  * Delay import of zipfile.
  * Verify shape of coordinates on write.
  * Fix integer coordinates to -5000..60536 conforming with ImageJ
  * Add subpixel_coordinates in frompoints for out-of-range integer
    coordinates.
  * Fix creating ROIs from float coordinates exceeding int16 range
  * Fix bottom-right bounds in ImagejRoi.frompoints.
  * Add type hints.
  * Change ImagejRoi to dataclass.
  * Drop support for Python 3.7 and numpy < 1.19 (NEP29).
  * Add enums for point types and sizes.
* Tue Apr 27 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2020.11.28:
  * Support group attribute.
  * Add roiread and roiwrite functions (#3).
  * Use UUID as default name of ROI in ImagejRoi.frompoints (#2).
- Do not build for Python 3.6, due to no NumPy.
* Thu Nov 26 2020 andy great <andythe_great@pm.me>
- Update to version 2020.8.13.
  * Support writing to ZIP file.
  * Support os.PathLike file names.
* Sat Aug  1 2020 andy great <andythe_great@pm.me>
- Update spec file to use python alternative.
* Mon Jun  1 2020 andy great <andythe_great@pm.me>
- Initial package release.
